==> zio-aws-schemas_2.13-5.17.116.2-sources.jar: zio/aws/schemas/model/DescribeDiscovererRequest.scala <==
package zio.aws.schemas.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.schemas.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class DescribeDiscovererRequest(discovererId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.schemas.model.DescribeDiscovererRequest = {
    import DescribeDiscovererRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.schemas.model.DescribeDiscovererRequest
      .builder()
      .discovererId(__string.unwrap(discovererId): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.schemas.model.DescribeDiscovererRequest.ReadOnly =
    zio.aws.schemas.model.DescribeDiscovererRequest.wrap(buildAwsValue())
}
object DescribeDiscovererRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.schemas.model.DescribeDiscovererRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.schemas.model.DescribeDiscovererRequest =
      zio.aws.schemas.model.DescribeDiscovererRequest(discovererId)
    def discovererId: __string
    def getDiscovererId: ZIO[Any, Nothing, __string] = ZIO.succeed(discovererId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.schemas.model.DescribeDiscovererRequest
  ) extends zio.aws.schemas.model.DescribeDiscovererRequest.ReadOnly {
    override val discovererId: __string =
      zio.aws.schemas.model.primitives.__string(impl.discovererId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.schemas.model.DescribeDiscovererRequest
  ): zio.aws.schemas.model.DescribeDiscovererRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-schemas_2.13-6.20.58.1-sources.jar: zio/aws/schemas/model/DescribeDiscovererRequest.scala <==
package zio.aws.schemas.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.schemas.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class DescribeDiscovererRequest(discovererId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.schemas.model.DescribeDiscovererRequest = {
    import DescribeDiscovererRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.schemas.model.DescribeDiscovererRequest
      .builder()
      .discovererId(discovererId: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.schemas.model.DescribeDiscovererRequest.ReadOnly =
    zio.aws.schemas.model.DescribeDiscovererRequest.wrap(buildAwsValue())
}
object DescribeDiscovererRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.schemas.model.DescribeDiscovererRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.schemas.model.DescribeDiscovererRequest =
      zio.aws.schemas.model.DescribeDiscovererRequest(discovererId)
    def discovererId: __string
    def getDiscovererId: ZIO[Any, Nothing, __string] = ZIO.succeed(discovererId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.schemas.model.DescribeDiscovererRequest
  ) extends zio.aws.schemas.model.DescribeDiscovererRequest.ReadOnly {
    override val discovererId: __string = impl.discovererId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.schemas.model.DescribeDiscovererRequest
  ): zio.aws.schemas.model.DescribeDiscovererRequest.ReadOnly = new Wrapper(
    impl
  )
}
